@@ -4,6 +4,7 @@ import (
 	"fmt"
 	"time"
 
+	"github.com/cloudskiff/driftctl/pkg/memstore"
 	globaloutput "github.com/cloudskiff/driftctl/pkg/output"
 	"github.com/jmespath/go-jmespath"
 	"github.com/sirupsen/logrus"
@@ -39,32 +40,36 @@ type DriftCTL struct {
 	remoteSupplier           resource.Supplier
 	iacSupplier              resource.Supplier
 	alerter                  alerter.AlerterInterface
-	analyzer                 analyser.Analyzer
+	analyzer                 *analyser.Analyzer
 	resourceFactory          resource.ResourceFactory
 	scanProgress             globaloutput.Progress
 	iacProgress              globaloutput.Progress
 	resourceSchemaRepository resource.SchemaRepositoryInterface
 	opts                     *ScanOptions
+	store                    memstore.Store
 }
 
 func NewDriftCTL(remoteSupplier resource.Supplier,
 	iacSupplier resource.Supplier,
 	alerter *alerter.Alerter,
+	analyzer *analyser.Analyzer,
 	resFactory resource.ResourceFactory,
 	opts *ScanOptions,
 	scanProgress globaloutput.Progress,
 	iacProgress globaloutput.Progress,
-	resourceSchemaRepository resource.SchemaRepositoryInterface) *DriftCTL {
+	resourceSchemaRepository resource.SchemaRepositoryInterface,
+	store memstore.Store) *DriftCTL {
 	return &DriftCTL{
 		remoteSupplier,
 		iacSupplier,
 		alerter,
-		analyser.NewAnalyzer(alerter, analyser.AnalyzerOptions{Deep: opts.Deep}),
+		analyzer,
 		resFactory,
 		scanProgress,
 		iacProgress,
 		resourceSchemaRepository,
 		opts,
+		store,
 	}
 }
 
@@ -95,8 +100,8 @@ func (d DriftCTL) Run() (*analyser.Analysis, error) {
 		middlewares.NewAwsDefaultRoute(),
 		middlewares.NewAwsNatGatewayEipAssoc(),
 		middlewares.NewAwsBucketPolicyExpander(d.resourceFactory),
-		middlewares.NewAwsSqsQueuePolicyExpander(d.resourceFactory, d.resourceSchemaRepository),
-		middlewares.NewAwsDefaultSqsQueuePolicy(),
+		middlewares.NewAwsSQSQueuePolicyExpander(d.resourceFactory, d.resourceSchemaRepository),
+		middlewares.NewAwsDefaultSQSQueuePolicy(),
 		middlewares.NewAwsSNSTopicPolicyExpander(d.resourceFactory, d.resourceSchemaRepository),
 		middlewares.NewAwsRoleManagedPolicyExpander(d.resourceFactory),
 		middlewares.NewTagsAllManager(),
@@ -127,10 +132,7 @@ func (d DriftCTL) Run() (*analyser.Analysis, error) {
 		}
 	}
 
-	logrus.Debug("Checking for driftignore")
-	driftIgnore := filter.NewDriftIgnore(d.opts.DriftignorePath)
-
-	analysis, err := d.analyzer.Analyze(remoteResources, resourcesFromState, driftIgnore)
+	analysis, err := d.analyzer.Analyze(remoteResources, resourcesFromState)
 	if err != nil {
 		return nil, err
 	}
@@ -138,6 +140,10 @@ func (d DriftCTL) Run() (*analyser.Analysis, error) {
 	analysis.Duration = time.Since(start)
 	analysis.Date = time.Now()
 
+	d.store.Bucket(memstore.TelemetryBucket).Set("total_resources", analysis.Summary().TotalResources)
+	d.store.Bucket(memstore.TelemetryBucket).Set("total_managed", analysis.Summary().TotalManaged)
+	d.store.Bucket(memstore.TelemetryBucket).Set("duration", uint(analysis.Duration.Seconds()+0.5))
+
 	return &analysis, nil
 }
 
