@@ -11,7 +11,7 @@ import (
 	"github.com/cloudskiff/driftctl/pkg/resource/aws"
 )
 
-func TestAwsDefaultSqsQueuePolicy_Execute(t *testing.T) {
+func TestAwsDefaultSQSQueuePolicy_Execute(t *testing.T) {
 	tests := []struct {
 		name               string
 		remoteResources    []resource.Resource
@@ -129,7 +129,7 @@ func TestAwsDefaultSqsQueuePolicy_Execute(t *testing.T) {
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			m := NewAwsDefaultSqsQueuePolicy()
+			m := NewAwsDefaultSQSQueuePolicy()
 			err := m.Execute(&tt.remoteResources, &tt.resourcesFromState)
 			if err != nil {
 				t.Fatal(err)
