@@ -8,19 +8,19 @@ import (
 )
 
 // Explodes policy found in aws_sqs_queue.policy from state resources to dedicated resources
-type AwsSqsQueuePolicyExpander struct {
+type AwsSQSQueuePolicyExpander struct {
 	resourceFactory          resource.ResourceFactory
 	resourceSchemaRepository resource.SchemaRepositoryInterface
 }
 
-func NewAwsSqsQueuePolicyExpander(resourceFactory resource.ResourceFactory, resourceSchemaRepository resource.SchemaRepositoryInterface) AwsSqsQueuePolicyExpander {
-	return AwsSqsQueuePolicyExpander{
+func NewAwsSQSQueuePolicyExpander(resourceFactory resource.ResourceFactory, resourceSchemaRepository resource.SchemaRepositoryInterface) AwsSQSQueuePolicyExpander {
+	return AwsSQSQueuePolicyExpander{
 		resourceFactory,
 		resourceSchemaRepository,
 	}
 }
 
-func (m AwsSqsQueuePolicyExpander) Execute(remoteResources, resourcesFromState *[]resource.Resource) error {
+func (m AwsSQSQueuePolicyExpander) Execute(remoteResources, resourcesFromState *[]resource.Resource) error {
 	for _, res := range *remoteResources {
 		if res.TerraformType() != aws.AwsSqsQueueResourceType {
 			continue
@@ -59,7 +59,7 @@ func (m AwsSqsQueuePolicyExpander) Execute(remoteResources, resourcesFromState *
 	return nil
 }
 
-func (m *AwsSqsQueuePolicyExpander) handlePolicy(queue *resource.AbstractResource, results *[]resource.Resource) error {
+func (m *AwsSQSQueuePolicyExpander) handlePolicy(queue *resource.AbstractResource, results *[]resource.Resource) error {
 	policy, exists := queue.Attrs.Get("policy")
 	if !exists || policy.(string) == "" {
 		queue.Attrs.SafeDelete([]string{"policy"})
@@ -86,7 +86,7 @@ func (m *AwsSqsQueuePolicyExpander) handlePolicy(queue *resource.AbstractResourc
 // It is mandatory since it's possible to have a aws_sqs_queue with an inline policy
 // AND a aws_sqs_queue_policy resource at the same time. At the end, on the AWS console,
 // the aws_sqs_queue_policy will be used.
-func (m *AwsSqsQueuePolicyExpander) hasPolicyAttached(queue *resource.AbstractResource, resourcesFromState *[]resource.Resource) bool {
+func (m *AwsSQSQueuePolicyExpander) hasPolicyAttached(queue *resource.AbstractResource, resourcesFromState *[]resource.Resource) bool {
 	for _, res := range *resourcesFromState {
 		if res.TerraformType() == aws.AwsSqsQueuePolicyResourceType &&
 			res.TerraformId() == queue.Id {
