@@ -26,7 +26,7 @@ func (e *EC2NatGatewayEnumerator) SupportedType() resource.ResourceType {
 func (e *EC2NatGatewayEnumerator) Enumerate() ([]resource.Resource, error) {
 	natGateways, err := e.repository.ListAllNatGateways()
 	if err != nil {
-		return nil, remoteerror.NewResourceEnumerationError(err, string(e.SupportedType()))
+		return nil, remoteerror.NewResourceListingError(err, string(e.SupportedType()))
 	}
 
 	results := make([]resource.Resource, len(natGateways))
