@@ -1,6 +1,9 @@
 package repository
 
 import (
+	"fmt"
+
+	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/sqs"
 	"github.com/aws/aws-sdk-go/service/sqs/sqsiface"
@@ -9,6 +12,7 @@ import (
 
 type SQSRepository interface {
 	ListAllQueues() ([]*string, error)
+	GetQueueAttributes(url string) (*sqs.GetQueueAttributesOutput, error)
 }
 
 type sqsRepository struct {
@@ -23,6 +27,25 @@ func NewSQSRepository(session *session.Session, c cache.Cache) *sqsRepository {
 	}
 }
 
+func (r *sqsRepository) GetQueueAttributes(url string) (*sqs.GetQueueAttributesOutput, error) {
+	cacheKey := fmt.Sprintf("sqsGetQueueAttributes_%s", url)
+	if v := r.cache.Get(cacheKey); v != nil {
+		return v.(*sqs.GetQueueAttributesOutput), nil
+	}
+
+	attributes, err := r.client.GetQueueAttributes(&sqs.GetQueueAttributesInput{
+		AttributeNames: aws.StringSlice([]string{sqs.QueueAttributeNamePolicy}),
+		QueueUrl:       &url,
+	})
+	if err != nil {
+		return nil, err
+	}
+
+	r.cache.Put(cacheKey, attributes)
+
+	return attributes, nil
+}
+
 func (r *sqsRepository) ListAllQueues() ([]*string, error) {
 	if v := r.cache.Get("sqsListAllQueues"); v != nil {
 		return v.([]*string), nil
