@@ -25,7 +25,7 @@ func (g *GithubMembershipEnumerator) SupportedType() resource.ResourceType {
 func (g *GithubMembershipEnumerator) Enumerate() ([]resource.Resource, error) {
 	ids, err := g.Membership.ListMembership()
 	if err != nil {
-		return nil, remoteerror.NewResourceEnumerationError(err, string(g.SupportedType()))
+		return nil, remoteerror.NewResourceListingError(err, string(g.SupportedType()))
 	}
 
 	results := make([]resource.Resource, len(ids))
