@@ -11,7 +11,7 @@ func TestAcc_Aws_EbsSnapshot(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.14.9",
 		Paths:            []string{"./testdata/acc/aws_ebs_snapshot"},
-		Args:             []string{"scan", "--filter", "Type=='aws_ebs_snapshot'"},
+		Args:             []string{"scan", "--filter", "Type=='aws_ebs_snapshot'", "--deep"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
