@@ -11,7 +11,7 @@ func TestAcc_Aws_KMSAlias(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.14.9",
 		Paths:            []string{"./testdata/acc/aws_kms_alias"},
-		Args:             []string{"scan", "--filter", "Type=='aws_kms_alias'"},
+		Args:             []string{"scan", "--filter", "Type=='aws_kms_alias'", "--deep"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
