@@ -19,7 +19,7 @@ func TestAcc_AwsRoute53HealthCheck(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.14.9",
 		Paths:            []string{"./testdata/acc/aws_route53_health_check"},
-		Args:             []string{"scan", "--filter", "Type=='aws_route53_health_check'"},
+		Args:             []string{"scan", "--filter", "Type=='aws_route53_health_check'", "--deep"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
