@@ -11,7 +11,7 @@ func TestAcc_Aws_SecurityGroupRule(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.14.9",
 		Paths:            []string{"./testdata/acc/aws_security_group_rule"},
-		Args:             []string{"scan", "--filter", "Type=='aws_security_group_rule'"},
+		Args:             []string{"scan", "--filter", "Type=='aws_security_group_rule'", "--deep"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
