@@ -19,12 +19,12 @@ import (
 	"github.com/cloudskiff/driftctl/test/acceptance/awsutils"
 )
 
-func TestAcc_AwsSqsQueue(t *testing.T) {
+func TestAcc_AwsSQSQueue(t *testing.T) {
 	var mutatedQueue string
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.14.9",
 		Paths:            []string{"./testdata/acc/aws_sqs_queue"},
-		Args:             []string{"scan", "--filter", "Type=='aws_sqs_queue'"},
+		Args:             []string{"scan", "--filter", "Type=='aws_sqs_queue'", "--deep"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
